@@ -25,7 +25,7 @@ def worker(func: Any) -> Any:
 def gather_data(account, region, instances):
     pass
 
-def create_tasks(df, func=gather_data, account="account_id", region="region")
+def create_tasks(df, func=gather_data, account="account_id", region="region"):
     records = json.loads(df.to_json(orient='records'))
     grouped_instances = groupby(records, lambda r: (r[account], r[region]))
     grouped_instances = {key: list(group) for key, group in grouped_instances}
