@@ -46,6 +46,8 @@ def _get_metric_data(**kargs):
         print(e)
         return None
     
+
+
 #####################################
 
 def _get_metric_data_queries(**kargs):
@@ -64,3 +66,44 @@ def _get_metric_data_queries(**kargs):
          },
          'Label': metric
       } for metric in kargs.get('MetricNames')]
+
+
+#####################################
+
+import boto3
+import datetime as dt  
+from itertools import groupby
+from datetime import datetime, timedelta
+
+def get_metrics(**kargs):
+    
+    client = kargs.get('session').client('cloudwatch')
+    iid = kargs.get('instance_id')
+    days = kargs.get('days',31)
+    period = kargs.get('period',300)
+    dimensions = [{"Name": "InstanceId", "Value": iid}]
+    queries = [
+        {
+            "Id": f'id_{i}', 
+            "MetricStat": { 
+                "Metric": { 
+                    "Namespace": nameSpace, 
+                    "MetricName": metricName, 
+                    "Dimensions": dimensions
+                },                
+                "Period": period,                
+                "Stat": stat
+                "Unit": unit
+            },     
+            "ReturnData": returnData
+            "Label": label,        
+        } for i, (nameSpace, metricName, stat, unit, returnData, label) in enumerate(kargs.get('queries'))
+    ]
+    
+    results = client.get_metric_data(
+        MetricDataQueries=queries,
+        StartTime = dt.datetime.today() - timedelta(days=days + 1),
+        EndTime=dt.datetime.today() - timedelta(days=1),
+    )["MetricDataResults"]
+    
+    return {k: list(group) for k, group in groupby(results, key=lambda r: r["Label"])}      
