@@ -86,3 +86,19 @@ class ddb_paginate(paginate):
         paginate.__init__(self, session, **kargs)
 
 #####################################
+
+class dms_paginate(paginate):
+    def __init__(self, session, **kargs):
+        kargs.update({'ep':self.name()})
+        kargs.update({'service':'dms'})
+        paginate.__init__(self, session, **kargs)
+
+#####################################
+
+class autoscaling_paginate(paginate):
+    def __init__(self, session, **kargs):
+        kargs.update({'ep':self.name()})
+        kargs.update({'service':'autoscaling'})
+        paginate.__init__(self, session, **kargs)
+
+#####################################
