@@ -18,7 +18,7 @@ def get_csv_data_from_s3(**kargs):
     s = kargs.get('session')
     b = kargs.get('bucket')
     k = kargs.get('key')
-    data = s3.get_assumed_object(s, bucket=b, key=k)
+    data = get_assumed_object(s, bucket=b, key=k)
     return pd.read_csv(sio(data), sep=","); 
 
 #####################################
